# Eatable Dataset Code

可食用数据集代码

## Target

支持大部分开放的深度学习相关数据集的解析和读取。

## Dependences

+ opencv-python
+ numpy

## Installation

```sh
python setup.py install
```

## Support

+ [x] Coco Dataset
+ [ ] Captcha
+ [ ] CatDog


## Wishes

所有听说、接触、使用此仓库的人，都能够获得暂时的快乐和永久不变的快乐。
